Calculates the step angles (in radians) of each segment, either relative to the previous segment or relative to the specified compass direction.
TrajAngles(trj, lag = 1, compass.direction = NULL)the trajectory whose whose angles are to be calculated.
Angles between every lag'th segment are calculated.
If not NULL, step angles are calculated
relative to this angle (in radians), otherwise they are calculated relative
to the previous step angle.
Step angles in radians, normalised so that -pi < angle <= pi.